==> secretsmanager-1.100.0-sources.jar: software/amazon/awscdk/services/secretsmanager/HostedRotationType.java <==
package software.amazon.awscdk.services.secretsmanager;

/**
 * Hosted rotation type.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-20T16:34:15.663Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.secretsmanager.$Module.class, fqn = "@aws-cdk/aws-secretsmanager.HostedRotationType")
public class HostedRotationType extends software.amazon.jsii.JsiiObject {

    protected HostedRotationType(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected HostedRotationType(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        MARIADB_MULTI_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "MARIADB_MULTI_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        MARIADB_SINGLE_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "MARIADB_SINGLE_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        MONGODB_MULTI_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "MONGODB_MULTI_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        MONGODB_SINGLE_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "MONGODB_SINGLE_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        MYSQL_MULTI_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "MYSQL_MULTI_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        MYSQL_SINGLE_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "MYSQL_SINGLE_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        ORACLE_MULTI_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "ORACLE_MULTI_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        ORACLE_SINGLE_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "ORACLE_SINGLE_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        POSTGRESQL_MULTI_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "POSTGRESQL_MULTI_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        POSTGRESQL_SINGLE_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "POSTGRESQL_SINGLE_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        REDSHIFT_MULTI_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "REDSHIFT_MULTI_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        REDSHIFT_SINGLE_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "REDSHIFT_SINGLE_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        SQLSERVER_MULTI_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "SQLSERVER_MULTI_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        SQLSERVER_SINGLE_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "SQLSERVER_SINGLE_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
    }

    /**
     * MariaDB Multi User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType MARIADB_MULTI_USER;

    /**
     * MariaDB Single User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType MARIADB_SINGLE_USER;

    /**
     * MongoDB Multi User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType MONGODB_MULTI_USER;

    /**
     * MongoDB Single User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType MONGODB_SINGLE_USER;

    /**
     * MySQL Multi User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType MYSQL_MULTI_USER;

    /**
     * MySQL Single User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType MYSQL_SINGLE_USER;

    /**
     * Oracle Multi User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType ORACLE_MULTI_USER;

    /**
     * Oracle Single User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType ORACLE_SINGLE_USER;

    /**
     * PostgreSQL Multi User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType POSTGRESQL_MULTI_USER;

    /**
     * PostgreSQL Single User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType POSTGRESQL_SINGLE_USER;

    /**
     * Redshift Multi User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType REDSHIFT_MULTI_USER;

    /**
     * Redshift Single User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType REDSHIFT_SINGLE_USER;

    /**
     * SQL Server Multi User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType SQLSERVER_MULTI_USER;

    /**
     * SQL Server Single User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType SQLSERVER_SINGLE_USER;

    /**
     * The type of rotation.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getName() {
        return software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * Whether the rotation uses the mutli user scheme.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Boolean getIsMultiUser() {
        return software.amazon.jsii.Kernel.get(this, "isMultiUser", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
    }
}

==> secretsmanager-1.173.0-sources.jar: software/amazon/awscdk/services/secretsmanager/HostedRotationType.java <==
package software.amazon.awscdk.services.secretsmanager;

/**
 * Hosted rotation type.
 * <p>
 * Example:
 * <p>
 * <blockquote><pre>
 * // The code below shows an example of how to instantiate this type.
 * // The values are placeholders you should change.
 * import software.amazon.awscdk.services.secretsmanager.*;
 * HostedRotationType hostedRotationType = HostedRotationType.MARIADB_MULTI_USER;
 * </pre></blockquote>
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.67.0 (build 2c027f5)", date = "2022-09-16T18:50:30.545Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.secretsmanager.$Module.class, fqn = "@aws-cdk/aws-secretsmanager.HostedRotationType")
public class HostedRotationType extends software.amazon.jsii.JsiiObject {

    protected HostedRotationType(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected HostedRotationType(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    static {
        MARIADB_MULTI_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "MARIADB_MULTI_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        MARIADB_SINGLE_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "MARIADB_SINGLE_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        MONGODB_MULTI_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "MONGODB_MULTI_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        MONGODB_SINGLE_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "MONGODB_SINGLE_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        MYSQL_MULTI_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "MYSQL_MULTI_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        MYSQL_SINGLE_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "MYSQL_SINGLE_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        ORACLE_MULTI_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "ORACLE_MULTI_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        ORACLE_SINGLE_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "ORACLE_SINGLE_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        POSTGRESQL_MULTI_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "POSTGRESQL_MULTI_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        POSTGRESQL_SINGLE_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "POSTGRESQL_SINGLE_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        REDSHIFT_MULTI_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "REDSHIFT_MULTI_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        REDSHIFT_SINGLE_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "REDSHIFT_SINGLE_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        SQLSERVER_MULTI_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "SQLSERVER_MULTI_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
        SQLSERVER_SINGLE_USER = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class, "SQLSERVER_SINGLE_USER", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.secretsmanager.HostedRotationType.class));
    }

    /**
     * MariaDB Multi User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType MARIADB_MULTI_USER;

    /**
     * MariaDB Single User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType MARIADB_SINGLE_USER;

    /**
     * MongoDB Multi User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType MONGODB_MULTI_USER;

    /**
     * MongoDB Single User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType MONGODB_SINGLE_USER;

    /**
     * MySQL Multi User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType MYSQL_MULTI_USER;

    /**
     * MySQL Single User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType MYSQL_SINGLE_USER;

    /**
     * Oracle Multi User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType ORACLE_MULTI_USER;

    /**
     * Oracle Single User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType ORACLE_SINGLE_USER;

    /**
     * PostgreSQL Multi User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType POSTGRESQL_MULTI_USER;

    /**
     * PostgreSQL Single User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType POSTGRESQL_SINGLE_USER;

    /**
     * Redshift Multi User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType REDSHIFT_MULTI_USER;

    /**
     * Redshift Single User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType REDSHIFT_SINGLE_USER;

    /**
     * SQL Server Multi User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType SQLSERVER_MULTI_USER;

    /**
     * SQL Server Single User.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public final static software.amazon.awscdk.services.secretsmanager.HostedRotationType SQLSERVER_SINGLE_USER;

    /**
     * The type of rotation.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.NotNull java.lang.String getName() {
        return software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * Whether the rotation uses the mutli user scheme.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public @org.jetbrains.annotations.Nullable java.lang.Boolean getIsMultiUser() {
        return software.amazon.jsii.Kernel.get(this, "isMultiUser", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
    }
}
